@@ -21,11 +21,14 @@ import matplotlib.pyplot as plt
 
 # defining material and experimental setup
 InAs = xu.materials.InAs
-energy= numpy.linspace(500,20000,5000) # 500 - 20000 eV
+energy = numpy.linspace(500, 20000, 5000)  # 500 - 20000 eV
 
-F = InAs.StructureFactorForEnergy(InAs.Q(1,1,1),energy)
+F = InAs.StructureFactorForEnergy(InAs.Q(1, 1, 1), energy)
 
-plt.figure(); plt.clf()
-plt.plot(energy,F.real,'k-',label='Re(F)')
-plt.plot(energy,F.imag,'r-',label='Imag(F)')
-plt.xlabel("Energy (eV)"); plt.ylabel("F"); plt.legend()
+plt.figure()
+plt.clf()
+plt.plot(energy, F.real, 'k-', label='Re(F)')
+plt.plot(energy, F.imag, 'r-', label='Imag(F)')
+plt.xlabel("Energy (eV)")
+plt.ylabel("F")
+plt.legend()
