@@ -20,11 +20,11 @@ import numpy
 
 # defining material and experimental setup
 InAs = xu.materials.InAs
-energy= 8048 # eV
+energy = 8048  # eV
 
 # calculate the structure factor for InAs (111) (222) (333)
-hkllist = [[1,1,1],[2,2,2],[3,3,3]]
+hkllist = [[1, 1, 1], [2, 2, 2], [3, 3, 3]]
 for hkl in hkllist:
     qvec = InAs.Q(hkl)
-    F = InAs.StructureFactor(qvec,energy)
-    print((" |F| = %8.3f" %numpy.abs(F)))
+    F = InAs.StructureFactor(qvec, energy)
+    print(" |F| = %8.3f" % numpy.abs(F))
