@@ -25,21 +25,26 @@ from .helper import xu_open
 from .. import config
 from ..exception import InputError
 
+
 class ImageReader(object):
+
     """
     parse CCD frames in the form of tiffs or binary data (*.bin)
     to numpy arrays. ignore the header since it seems to contain
     no useful data
 
     The routine was tested so far with
-     RoperScientific files with 4096x4096 pixels created at Hasylab Hamburg,
-     which save an 16bit integer per point.
-     Perkin Elmer images created at Hasylab Hamburg with 2048x2048 pixels.
+
+    1. RoperScientific files with 4096x4096 pixels created at Hasylab Hamburg,
+       which save an 16bit integer per point.
+    2. Perkin Elmer images created at Hasylab Hamburg with 2048x2048 pixels.
     """
-    def __init__(self,nop1,nop2,hdrlen=0,flatfield=None,darkfield=None,dtype=numpy.int16,byte_swap=False):
+
+    def __init__(self, nop1, nop2, hdrlen=0, flatfield=None, darkfield=None,
+                 dtype=numpy.int16, byte_swap=False):
         """
-        initialize the ImageReader reader, which includes setting the dimension of
-        the images as well as defining the data used for flat- and darkfield
+        initialize the ImageReader reader, which includes setting the dimension
+        of the images as well as defining the data used for flat- and darkfield
         correction!
 
         Parameter
@@ -49,7 +54,8 @@ class ImageReader(object):
          hdrlen:    length of the file header which should be ignored
          flatfield: filename or data for flatfield correction. supported file
                     types include (*.bin/*.tif (also compressed .xz or .gz)
-                    and *.npy files). otherwise a 2D numpy array should be given
+                    and *.npy files). otherwise a 2D numpy array should be
+                    given
          darkfield: filename or data for darkfield correction. same types as
                     for flat field are supported.
          dtype:     datatype of the stored values (default: numpy.int16)
@@ -57,39 +63,47 @@ class ImageReader(object):
         """
 
         # save number of pixels per image
-        self.nop1= nop1
-        self.nop2= nop2
+        self.nop1 = nop1
+        self.nop2 = nop2
         self.dtype = dtype
         self.hdrlen = hdrlen
         self.byteswap = byte_swap
 
         # read flatfield
         if flatfield:
-            if isinstance(flatfield,str):
+            if isinstance(flatfield, str):
                 if os.path.splitext(flatfield)[1] == '.npy':
                     self.flatfield = numpy.load(flatfield)
-                elif os.path.splitext(flatfield)[1] in ['.gz','.xz','.bin','.tif']:
-                    self.flatfield = self.readImage(flatfield) # read without flatc and darkc
+                elif os.path.splitext(flatfield)[1] in \
+                        ['.gz', '.xz', '.bin', '.tif']:
+                    # read without flatc and darkc
+                    self.flatfield = self.readImage(flatfield)
                 else:
-                    raise InputError("Error: unknown filename for flatfield correction!")
-            elif isinstance(flatfield,numpy.ndarray):
+                    raise InputError("Error: unknown filename for "
+                                     "flatfield correction!")
+            elif isinstance(flatfield, numpy.ndarray):
                 self.flatfield = flatfield
             else:
-                raise InputError("Error: unsupported type for flatfield correction!")
+                raise InputError("Error: unsupported type for "
+                                 "flatfield correction!")
 
         # read darkfield
         if darkfield:
-            if isinstance(darkfield,str):
+            if isinstance(darkfield, str):
                 if os.path.splitext(darkfield)[1] == '.npy':
                     self.darkfield = numpy.load(darkfield)
-                elif os.path.splitext(darkfield)[1] in ['.gz','.xz','.bin','.tif']:
-                    self.darkfield = self.readImage(darkfield) # read without flatc and darkc
+                elif os.path.splitext(darkfield)[1] in \
+                        ['.gz', '.xz', '.bin', '.tif']:
+                    # read without flatc and darkc
+                    self.darkfield = self.readImage(darkfield)
                 else:
-                    raise InputError("Error: unknown filename for darkfield correction!")
-            elif isinstance(darkfield,numpy.ndarray):
+                    raise InputError("Error: unknown filename for "
+                                     "darkfield correction!")
+            elif isinstance(darkfield, numpy.ndarray):
                 self.darkfield = darkfield
             else:
-                raise InputError("Error: unsupported type for darkfield correction!")
+                raise InputError("Error: unsupported type for "
+                                 "darkfield correction!")
 
         if flatfield:
             self.flatc = True
@@ -104,8 +118,7 @@ class ImageReader(object):
         else:
             self.darkc = False
 
-
-    def readImage(self,filename):
+    def readImage(self, filename):
         """
         read image file
         and correct for dark- and flatfield in case the necessary data are
@@ -121,14 +134,16 @@ class ImageReader(object):
         """
 
         if config.VERBOSITY >= config.INFO_ALL:
-            print("XU.io.ImageReader.readImage: file %s"%(filename))
+            print("XU.io.ImageReader.readImage: file %s" % (filename))
             t1 = time.time()
 
         if filename[-2:] == 'xz':
             if config.VERBOSITY >= config.INFO_ALL:
-                print("XU.io.ImageReader.readImage: uncompressing file %s"%(filename))
+                print("XU.io.ImageReader.readImage: uncompressing file %s"
+                      % (filename))
 
-            subprocess.call("xz --decompress --verbose --keep %s" %(filename),shell=True)
+            subprocess.call("xz --decompress --verbose --keep %s"
+                            % (filename), shell=True)
             fh = open(filename[:-3], 'rb')
         else:
             fh = xu_open(filename)
@@ -137,32 +152,38 @@ class ImageReader(object):
         fh.seek(self.hdrlen)
         # read image
         if filename[-2:] == 'gz':
-            img = numpy.fromstring(fh.read(),dtype=self.dtype,count=self.nop1*self.nop2)
+            img = numpy.fromstring(fh.read(), dtype=self.dtype,
+                                   count=self.nop1 * self.nop2)
         else:
-            img = numpy.fromfile(fh,dtype=self.dtype,count=self.nop1*self.nop2)
+            img = numpy.fromfile(fh, dtype=self.dtype,
+                                 count=self.nop1 * self.nop2)
         if self.byteswap:
             img = img.byteswap()
-        img.shape = (self.nop1,self.nop2) # reshape the data
+        img.shape = (self.nop1, self.nop2)  # reshape the data
         # darkfield correction
         if self.darkc:
-            imgf = (img-self.darkfield).astype(numpy.float32)
-        else: imgf = img.astype(numpy.float32)
+            imgf = (img - self.darkfield).astype(numpy.float32)
+        else:
+            imgf = img.astype(numpy.float32)
         # kill negativ pixels
-        #numpy.clip(imgf,1e-6,numpy.Inf,out=imgf)
+        # numpy.clip(imgf,1e-6,numpy.Inf,out=imgf)
         # flatfield correction
         if self.flatc:
-            imgf = imgf/self.flatfield
+            imgf = imgf / self.flatfield
         fh.close()
         if os.path.splitext(filename)[1] == '.xz':
-            subprocess.call(["rm","%s"%(filename[:-3])])
+            subprocess.call(["rm", "%s" % (filename[:-3])])
 
         if config.VERBOSITY >= config.INFO_ALL:
             t2 = time.time()
-            print("XU.io.ImageReader.readImage: parsing time %8.3f"%(t2-t1))
+            print("XU.io.ImageReader.readImage: parsing time %8.3f"
+                  % (t2 - t1))
 
         return imgf
 
+
 class PerkinElmer(ImageReader):
+
     """
     parse PerkinElmer CCD frames (*.bin) to numpy arrays
     Ignore the header since it seems to contain no useful data
@@ -170,10 +191,11 @@ class PerkinElmer(ImageReader):
     The routine was tested only for files with 2048x2048 pixel images
     created at Hasylab Hamburg which save an 32bit float per point.
     """
-    def __init__(self,**keyargs):
+
+    def __init__(self, **keyargs):
         """
-        initialize the PerkinElmer reader, which includes setting the dimension of
-        the images as well as defining the data used for flat- and darkfield
+        initialize the PerkinElmer reader, which includes setting the dimension
+        of the images as well as defining the data used for flat- and darkfield
         correction!
 
         Parameter
@@ -186,11 +208,12 @@ class PerkinElmer(ImageReader):
                      for flat field are supported.
         """
 
-        ImageReader.__init__(self,2048,2048,hdrlen=8,dtype=numpy.float32,byte_swap=False,**keyargs)
-
+        ImageReader.__init__(self, 2048, 2048, hdrlen=8, dtype=numpy.float32,
+                             byte_swap=False, **keyargs)
 
 
 class RoperCCD(ImageReader):
+
     """
     parse RoperScientific CCD frames (*.bin) to numpy arrays
     Ignore the header since it seems to contain no useful data
@@ -198,7 +221,8 @@ class RoperCCD(ImageReader):
     The routine was tested only for files with 4096x4096 pixel images
     created at Hasylab Hamburg which save an 16bit integer per point.
     """
-    def __init__(self,**keyargs):
+
+    def __init__(self, **keyargs):
         """
         initialize the RoperCCD reader, which includes setting the dimension of
         the images as well as defining the data used for flat- and darkfield
@@ -214,5 +238,5 @@ class RoperCCD(ImageReader):
                      for flat field are supported.
         """
 
-        ImageReader.__init__(self,4096,4096,hdrlen=216,dtype=numpy.int16,byte_swap=False,**keyargs)
-
+        ImageReader.__init__(self, 4096, 4096, hdrlen=216, dtype=numpy.int16,
+                             byte_swap=False, **keyargs)
