@@ -19,6 +19,7 @@
 from .transforms import Transform
 from .transforms import CoordinateTransform
 from .transforms import AxisToZ
+from .transforms import AxisToZ_keepXY
 from .transforms import Cij2Cijkl
 from .transforms import Cijkl2Cij
 from .transforms import XRotation
@@ -47,12 +48,18 @@ from .functions import Lorentz1d_der_x
 from .functions import Lorentz1d_der_p
 from .functions import Lorentz2d
 from .functions import PseudoVoigt1d
+from .functions import PseudoVoigt2d
+from .functions import Gauss1dArea
+from .functions import Gauss2dArea
+from .functions import Lorentz1dArea
 from .functions import PseudoVoigt1dArea
+from .functions import multPeak1d
+from .functions import multPeak2d
 
 from .fit import fit_peak2d
 from .fit import gauss_fit
 from .fit import peak_fit
 from .fit import multPeakFit
-from .fit import multPeakPlot 
+from .fit import multPeakPlot
 from .fit import multGaussFit
-from .fit import multGaussPlot 
+from .fit import multGaussPlot
