@@ -14,27 +14,30 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2013,2014 Dominik Kriegner <dominik.kriegner@gmail.com>
+ * Copyright (C) 2013, 2014 Dominik Kriegner <dominik.kriegner@gmail.com>
  * Copyright (C) 2013 Eugen Wintersberger <eugen.wintersberger@desy.de>
  *
 */
-
 #include <Python.h>
 
 #define NPY_NO_DEPRECATED_API NPY_1_7_API_VERSION
 #define PY_ARRAY_UNIQUE_SYMBOL XU_UNIQUE_SYMBOL
 #include <numpy/arrayobject.h>
 
+
 /* functions from block_average.c */
 extern PyObject* block_average1d(PyObject *self, PyObject *args);
 extern PyObject* block_average2d(PyObject *self, PyObject *args);
 extern PyObject* block_average_PSD(PyObject *self, PyObject *args);
 
+/* functions from gridder1d.c */
+extern PyObject* pygridder1d(PyObject *self, PyObject *args);
+
 /* functions from gridder2d.c */
-extern PyObject* pygridder2d(PyObject *self,PyObject *args);
+extern PyObject* pygridder2d(PyObject *self, PyObject *args);
 
 /* function from gridder3d.c */
-extern PyObject* pygridder3d(PyObject *self,PyObject *args);
+extern PyObject* pygridder3d(PyObject *self, PyObject *args);
 
 /* functions from qconversion.c */
 extern PyObject* ang2q_conversion(PyObject *self, PyObject *args);
@@ -51,7 +54,7 @@ extern PyObject* ang2q_conversion_area_sd(PyObject *self, PyObject *args);
 extern PyObject* cbfread(PyObject *self, PyObject *args);
 
 static PyMethodDef XRU_Methods[] = {
-    {"block_average1d",  (PyCFunction)block_average1d, METH_VARARGS,
+    {"block_average1d", (PyCFunction)block_average1d, METH_VARARGS,
      "block average for one-dimensional numpy double array\n\n"
      "Parameters \n"
      "----------\n"
@@ -60,24 +63,24 @@ static PyMethodDef XRU_Methods[] = {
      "Returns\n"
      "-------\n"
      " block_av:   block averaged output array\n"
-     "             size = ceil(N/Nav) \n"
+     "             size = ceil(N / Nav) \n"
     },
-    {"block_average2d",  block_average2d, METH_VARARGS,
+    {"block_average2d", block_average2d, METH_VARARGS,
      "2D block average for one CCD frame\n\n"
      "Parameters\n"
      "----------\n"
      " ccd:     input array/CCD frame\n"
      "          size = (Nch2, Nch1) \n"
      "          Nch1 is the fast varying index\n"
-     " Nav1,2:  number of channels to average in each dimension\n"
+     " Nav1, 2:  number of channels to average in each dimension\n"
      "          in total a block of Nav1 x Nav2 is averaged\n"
      "\n"
      "Returns\n"
      "-------\n"
      " block_av:     block averaged output array\n"
-     "               size = (ceil(Nch2/Nav2) , ceil(Nch1/Nav1))\n"
+     "               size = (ceil(Nch2 / Nav2) , ceil(Nch1 / Nav1))\n"
     },
-    {"block_average_PSD",  block_average_PSD, METH_VARARGS,
+    {"block_average_PSD", block_average_PSD, METH_VARARGS,
      "1D block average for a bunch of PSD spectra in a 2D array\n"
      "\n"
      "Parameters\n"
@@ -91,7 +94,18 @@ static PyMethodDef XRU_Methods[] = {
      " block_av:    block averaged output array\n"
      "              size = (Nspec , ceil(Nch/Nav)) (out)\n"
     },
-    {"gridder2d",pygridder2d,METH_VARARGS,
+    {"gridder1d", pygridder1d, METH_VARARGS,
+     "Function performs 1D gridding on 1D input data. \n\n"
+     "Parameters\n"
+     "----------\n"
+     "  x ...... input x-values (1D numpy array - float64)\n"
+     "  data ... input data (1D numpy array - float64)\n"
+     "  nx ..... number of grid points in x-direction\n"
+     "  xmin ... minimum x-value of the grid\n"
+     "  xmax ... maximum x-value of the grid\n"
+     "  out .... output data\n"
+    },
+    {"gridder2d", pygridder2d, METH_VARARGS,
      "Function performs 2D gridding on 1D input data. \n\n"
      "Parameters\n"
      "----------\n"
@@ -106,7 +120,7 @@ static PyMethodDef XRU_Methods[] = {
      "  ymax ... minimum y-value of the grid\n"
      "  out .... output data\n"
     },
-    {"gridder3d",pygridder3d,METH_VARARGS,
+    {"gridder3d", pygridder3d, METH_VARARGS,
      "Function performs 2D gridding on 1D input data. \n\n"
      "Parameters\n"
      "----------\n"
@@ -131,19 +145,24 @@ static PyMethodDef XRU_Methods[] = {
      "\n"
      "Parameters\n"
      "----------\n"
-     "  sampleAngles .... angular positions of the sample goniometer (Npoints,Ns)\n"
-     "  detectorAngles .. angular positions of the detector goniometer (Npoints,Nd)\n"
-     "  ri .............. direction of primary beam (length irrelevant) (angles zero) \n"
+     "  sampleAngles .... angular positions of the sample goniometer\n"
+     "                    (Npoints, Ns)\n"
+     "  detectorAngles .. angular positions of the detector goniometer\n"
+     "                    (Npoints, Nd)\n"
+     "  ri .............. direction of primary beam (length irrelevant)\n"
+     "                    (angles zero)\n"
      "  sampleAxis ...... string with sample axis directions\n"
      "  detectorAxis .... string with detector axis directions\n"
      "  kappadir ........ rotation axis of a possible kappa circle\n"
-     "  UB .............. orientation matrix and reciprocal space conversion of investigated crystal (3,3)\n"
+     "  UB .............. orientation matrix and reciprocal space conversion\n"
+     "                    of investigated crystal (3, 3)\n"
      "  lambda .......... wavelength of the used x-rays (Angstreom)\n"
-     "  nthreads ........ number of threads to use in parallel section of the code\n"
+     "  nthreads ........ number of threads to use in parallel section of\n"
+     "                    the code\n"
      "\n"
      "Returns\n"
      "-------\n"
-     " qpos .......... momentum transfer (Npoints,3)\n"
+     " qpos .......... momentum transfer (Npoints, 3)\n"
     },
     {"ang2q_conversion_linear", ang2q_conversion_linear, METH_VARARGS,
      "conversion of Npoints of goniometer positions to reciprocal space\n"
@@ -152,9 +171,11 @@ static PyMethodDef XRU_Methods[] = {
      "\n"
      "Parameters\n"
      "----------\n"
-     " sampleAngles .... angular positions of the goniometer (Npoints,Ns)\n"
-     " detectorAngles .. angular positions of the detector goniometer (Npoints,Nd)\n"
-     " rcch ............ direction + distance of center channel (angles zero)\n"
+     " sampleAngles .... angular positions of the goniometer (Npoints, Ns)\n"
+     " detectorAngles .. angular positions of the detector goniometer\n"
+     "                   (Npoints, Nd)\n"
+     " rcch ............ direction + distance of center channel\n"
+     "                   (angles zero)\n"
      " sampleAxis ...... string with sample axis directions\n"
      " detectorAxis .... string with detector axis directions\n"
      " kappadir ........ rotation axis of a possible kappa circle\n"
@@ -163,13 +184,15 @@ static PyMethodDef XRU_Methods[] = {
      " roi ............. region of interest of the detector\n"
      " dir ............. direction of the detector, e.g.: 'x+'\n"
      " tilt ............ tilt of the detector direction from dir\n"
-     " UB .............. orientation matrix and reciprocal space conversion of investigated crystal (9)\n"
+     " UB .............. orientation matrix and reciprocal space conversion\n"
+     "                   of investigated crystal (9)\n"
      " lambda .......... wavelength of the used x-rays in Angstroem\n"
-     " nthreads ........ number of threads to use in parallel section of the code\n"
+     " nthreads ........ number of threads to use in parallel section of\n"
+     "                   the code\n"
      "\n"
      "Returns\n"
      "-------\n"
-     " qpos ............ momentum transfer (Npoints*Nch,3)\n"
+     " qpos ............ momentum transfer (Npoints * Nch, 3)\n"
      " \n"
     },
     {"ang2q_conversion_area", ang2q_conversion_area, METH_VARARGS,
@@ -179,75 +202,90 @@ static PyMethodDef XRU_Methods[] = {
      "\n"
      "Parameters\n"
      "----------\n"
-     "  sampleAngles .... angular positions of the sample goniometer (Npoints,Ns)\n"
-     "  detectorAngles .. angular positions of the detector goniometer (Npoints,Nd)\n"
+     "  sampleAngles .... angular positions of the sample goniometer\n"
+     "                    (Npoints, Ns)\n"
+     "  detectorAngles .. angular positions of the detector goniometer\n"
+     "                    (Npoints, Nd)\n"
      "  rcch ............ direction + distance of center pixel (angles zero)\n"
      "  sampleAxis ...... string with sample axis directions\n"
      "  detectorAxis .... string with detector axis directions\n"
      "  kappadir ...... rotation axis of a possible kappa circle\n"
      "  cch1 ............ center channel of the detector\n"
      "  cch2 ............ center channel of the detector\n"
-     "  dpixel1 ......... width of one pixel in first direction, same unit as distance rcch\n"
-     "  dpixel2 ......... width of one pixel in second direction, same unit as distance rcch\n"
-     "  roi ............. region of interest for the area detector [dir1min,dir1max,dir2min,dir2max]\n"
+     "  dpixel1 ......... width of one pixel in first direction, same unit\n"
+     "                    as distance rcch\n"
+     "  dpixel2 ......... width of one pixel in second direction, same unit\n"
+     "                    as distance rcch\n"
+     "  roi ............. region of interest for the area detector\n"
+     "                    [dir1min, dir1max, dir2min, dir2max]\n"
      "  dir1 ............ first direction of the detector, e.g.: 'x+'\n"
      "  dir2 ............ second direction of the detector, e.g.: 'z+'\n"
      "  tiltazimuth ..... azimuth of the tilt\n"
-     "  tilt ............ tilt of the detector plane (rotation around axis normal to the direction\n"
-     "                    given by the tiltazimuth\n"
-     "  UB .............. orientation matrix and reciprocal space conversion of investigated crystal (3,3)\n"
+     "  tilt ............ tilt of the detector plane (rotation around axis\n"
+     "                    normal to the direction given by the tiltazimuth\n"
+     "  UB .............. orientation matrix and reciprocal space conversion\n"
+     "                    of investigated crystal (3, 3)\n"
      "  lambda .......... wavelength of the used x-rays \n"
-     "  nthreads ........ number of threads to use in parallel section of the code\n"
+     "  nthreads ........ number of threads to use in parallel section of\n"
+     "                    the code\n"
      "\n"
      "Returns\n"
      "-------\n"
-     " qpos ............ momentum transfer (Npoints*Npix1*Npix2,3)\n"
+     " qpos ............ momentum transfer (Npoints * Npix1 * Npix2, 3)\n"
      "\n"
     },
     {"ang2q_conversion_area_pixel", ang2q_conversion_area_pixel, METH_VARARGS,
      "conversion of Npoints of detector positions to Q\n"
      "for a area detector with a given pixel size mounted along one of\n"
-     "the coordinate axis. This function only calculates the q-position for the\n"
-     "pairs of pixel numbers (n1,n2) given in the input and should therefore be\n"
-     "used only for detector calibration purposes.\n"
+     "the coordinate axis. This function only calculates the q-position for\n"
+     "the pairs of pixel numbers (n1, n2) given in the input and should\n"
+     "therefore be used only for detector calibration purposes.\n"
      "\n"
      "Parameters\n"
      "----------\n"
-     " detectorAngles .. angular positions of the detector goniometer (Npoints,Nd)\n"
+     " detectorAngles .. angular positions of the detector goniometer\n"
+     "                   (Npoints, Nd)\n"
      " n1 .............. detector pixel numbers dim1 (Npoints)\n"
      " n2 .............. detector pixel numbers dim2 (Npoints)\n"
      " rcch ............ direction + distance of center pixel (angles zero)\n"
      " detectorAxis .... string with detector axis directions\n"
      " cch1 ............ center channel of the detector\n"
      " cch2 ............ center channel of the detector\n"
-     " dpixel1 ......... width of one pixel in first direction, same unit as distance rcch\n"
-     " dpixel2 ......... width of one pixel in second direction, same unit as distance rcch\n"
+     " dpixel1 ......... width of one pixel in first direction, same unit as\n"
+     "                   distance rcch\n"
+     " dpixel2 ......... width of one pixel in second direction, same unit\n"
+     "                   as distance rcch\n"
      " dir1 ............ first direction of the detector, e.g.: 'x+'\n"
      " dir2 ............ second direction of the detector, e.g.: 'z+'\n"
      " tiltazimuth ..... azimuth of the tilt\n"
-     " tilt ............ tilt of the detector plane (rotation around axis normal to the direction\n"
-     "                   given by the tiltazimuth\n"
+     " tilt ............ tilt of the detector plane (rotation around axis\n"
+     "                   normal to the direction given by the tiltazimuth\n"
      " lambda .......... wavelength of the used x-rays\n"
-     " nthreads ........ number of threads to use in parallel section of the code\n"
+     " nthreads ........ number of threads to use in parallel section of the\n"
+     "                   code\n"
      "\n"
      "Returns\n"
      "-------\n"
-     " qpos ............ momentum transfer (Npoints,3)\n"
+     " qpos ............ momentum transfer (Npoints, 3)\n"
     },
-    {"ang2q_conversion_area_pixel2", ang2q_conversion_area_pixel2, METH_VARARGS,
-     "conversion of Npoints of detector positions to Q\n"
+    {"ang2q_conversion_area_pixel2",
+     ang2q_conversion_area_pixel2, METH_VARARGS,
+     "conversion of Npoints of detector positions to Q.\n"
      "for a area detector with a given pixel size mounted along one of\n"
-     "the coordinate axis. This function only calculates the q-position for the\n"
-     "pairs of pixel numbers (n1,n2) given in the input and should therefore be\n"
-     "used only for detector calibration purposes.\n"
+     "the coordinate axis. This function only calculates the q-position for\n"
+     "the pairs of pixel numbers (n1, n2) given in the input and should\n"
+     "therefore be used only for detector calibration purposes.\n"
      "\n"
-     "This variant of this function also takes a sample orientation matrix as well as the sample goniometer\n"
-     "as input to allow for a simultaneous fit of reference samples orientation\n"
+     "This variant of this function also takes a sample orientation matrix\n"
+     "as well as the sample goniometer as input to allow for a simultaneous\n"
+     "fit of reference samples orientation\n"
      "\n"
      "Parameters\n"
      "----------\n"
-     " sampleAngles .... angular positions of the sample goniometer (Npoints,Ns)\n"
-     " detectorAngles .. angular positions of the detector goniometer (Npoints,Nd)\n"
+     " sampleAngles .... angular positions of the sample goniometer\n"
+     "                   (Npoints, Ns)\n"
+     " detectorAngles .. angular positions of the detector goniometer\n"
+     "                   (Npoints, Nd)\n"
      " n1 .............. detector pixel numbers dim1 (Npoints)\n"
      " n2 .............. detector pixel numbers dim2 (Npoints)\n"
      " rcch ............ direction + distance of center pixel (angles zero)\n"
@@ -255,41 +293,52 @@ static PyMethodDef XRU_Methods[] = {
      " detectorAxis .... string with detector axis directions\n"
      " cch1 ............ center channel of the detector\n"
      " cch2 ............ center channel of the detector\n"
-     " dpixel1 ......... width of one pixel in first direction, same unit as distance rcch\n"
-     " dpixel2 ......... width of one pixel in second direction, same unit as distance rcch \n"
+     " dpixel1 ......... width of one pixel in first direction, same unit as\n"
+     "                   distance rcch\n"
+     " dpixel2 ......... width of one pixel in second direction, same unit\n"
+     "                   as distance rcch \n"
      " dir1 ............ first direction of the detector, e.g.: 'x+'\n"
      " dir2 ............ second direction of the detector, e.g.: 'z+'\n"
      " tiltazimuth ..... azimuth of the tilt\n"
-     " tilt ............ tilt of the detector plane (rotation around axis normal to the direction\n"
-     "                   given by the tiltazimuth\n"
-     " UB .............. orientation matrix and reciprocal space conversion of investigated crystal (3,3)\n"
+     " tilt ............ tilt of the detector plane (rotation around axis\n"
+     "                   normal to the direction given by the tiltazimuth\n"
+     " UB .............. orientation matrix and reciprocal space conversion\n"
+     "                   of investigated crystal (3, 3)\n"
      " lambda .......... wavelength of the used x-rays\n"
-     " nthreads ........ number of threads to use in parallel section of the code\n"
+     " nthreads ........ number of threads to use in parallel section of the\n"
+     "                   code\n"
      "\n"
      "Returns\n"
      "-------\n"
-     " qpos ............ momentum transfer (Npoints,3)\n"
+     " qpos ............ momentum transfer (Npoints, 3)\n"
     },
     {"ang2q_conversion_sd", ang2q_conversion_sd, METH_VARARGS,
      "conversion of Npoints of goniometer positions to reciprocal space\n"
-     "for a setup with point detector considering a sample displacement error\n"
+     "for a setup with point detector considering a sample displacement\n"
+     "error\n"
      "\n"
      "Parameters\n"
      "----------\n"
-     "  sampleAngles .... angular positions of the sample goniometer (Npoints,Ns)\n"
-     "  detectorAngles .. angular positions of the detector goniometer (Npoints,Nd)\n"
-     "  ri .............. direction of primary beam (length irrelevant) (angles zero) \n"
+     "  sampleAngles .... angular positions of the sample goniometer\n"
+     "                    (Npoints, Ns)\n"
+     "  detectorAngles .. angular positions of the detector goniometer\n"
+     "                    (Npoints, Nd)\n"
+     "  ri .............. direction of primary beam (length irrelevant)\n"
+     "                    (angles zero)\n"
      "  sampleAxis ...... string with sample axis directions\n"
      "  detectorAxis .... string with detector axis directions\n"
      "  kappadir ........ rotation axis of a possible kappa circle\n"
-     "  UB .............. orientation matrix and reciprocal space conversion of investigated crystal (3,3)\n"
-     "  sampledis ....... sample displacement vector in relative units of the detector distance\n"
+     "  UB .............. orientation matrix and reciprocal space conversion\n"
+     "                    of investigated crystal (3, 3)\n"
+     "  sampledis ....... sample displacement vector in relative units of\n"
+     "                    the detector distance\n"
      "  lambda .......... wavelength of the used x-rays (Angstreom)\n"
-     "  nthreads ........ number of threads to use in parallel section of the code\n"
+     "  nthreads ........ number of threads to use in parallel section of\n"
+     "                    the code\n"
      "\n"
      "Returns\n"
      "-------\n"
-     " qpos .......... momentum transfer (Npoints,3)\n"
+     " qpos .......... momentum transfer (Npoints, 3)\n"
     },
     {"ang2q_conversion_linear_sd", ang2q_conversion_linear_sd, METH_VARARGS,
      "conversion of Npoints of goniometer positions to reciprocal space\n"
@@ -298,9 +347,11 @@ static PyMethodDef XRU_Methods[] = {
      "\n"
      "Parameters\n"
      "----------\n"
-     " sampleAngles .... angular positions of the goniometer (Npoints,Ns)\n"
-     " detectorAngles .. angular positions of the detector goniometer (Npoints,Nd)\n"
-     " rcch ............ direction + distance of center channel (angles zero)\n"
+     " sampleAngles .... angular positions of the goniometer (Npoints, Ns)\n"
+     " detectorAngles .. angular positions of the detector goniometer\n"
+     "                   (Npoints, Nd)\n"
+     " rcch ............ direction + distance of center channel (angles\n"
+     "                   zero)\n"
      " sampleAxis ...... string with sample axis directions\n"
      " detectorAxis .... string with detector axis directions\n"
      " kappadir ........ rotation axis of a possible kappa circle\n"
@@ -309,14 +360,17 @@ static PyMethodDef XRU_Methods[] = {
      " roi ............. region of interest of the detector\n"
      " dir ............. direction of the detector, e.g.: 'x+'\n"
      " tilt ............ tilt of the detector direction from dir\n"
-     " UB .............. orientation matrix and reciprocal space conversion of investigated crystal (9)\n"
-     " sampledis ....... sample displacement vector in same unit as the detector distance\n"
+     " UB .............. orientation matrix and reciprocal space conversion\n"
+     "                   of investigated crystal (9)\n"
+     " sampledis ....... sample displacement vector in same unit as the\n"
+     "                   detector distance\n"
      " lambda .......... wavelength of the used x-rays in Angstroem\n"
-     " nthreads ........ number of threads to use in parallel section of the code\n"
+     " nthreads ........ number of threads to use in parallel section of the\n"
+     "                   code\n"
      "\n"
      "Returns\n"
      "-------\n"
-     " qpos ............ momentum transfer (Npoints*Nch,3)\n"
+     " qpos ............ momentum transfer (Npoints * Nch, 3)\n"
      " \n"
     },
     {"ang2q_conversion_area_sd", ang2q_conversion_area_sd, METH_VARARGS,
@@ -326,30 +380,38 @@ static PyMethodDef XRU_Methods[] = {
      "\n"
      "Parameters\n"
      "----------\n"
-     "  sampleAngles .... angular positions of the sample goniometer (Npoints,Ns)\n"
-     "  detectorAngles .. angular positions of the detector goniometer (Npoints,Nd)\n"
+     "  sampleAngles .... angular positions of the sample goniometer\n"
+     "                    (Npoints, Ns)\n"
+     "  detectorAngles .. angular positions of the detector goniometer\n"
+     "                    (Npoints, Nd)\n"
      "  rcch ............ direction + distance of center pixel (angles zero)\n"
      "  sampleAxis ...... string with sample axis directions\n"
      "  detectorAxis .... string with detector axis directions\n"
-     "  kappadir ...... rotation axis of a possible kappa circle\n"
+     "  kappadir ........ rotation axis of a possible kappa circle\n"
      "  cch1 ............ center channel of the detector\n"
      "  cch2 ............ center channel of the detector\n"
-     "  dpixel1 ......... width of one pixel in first direction, same unit as distance rcch\n"
-     "  dpixel2 ......... width of one pixel in second direction, same unit as distance rcch\n"
-     "  roi ............. region of interest for the area detector [dir1min,dir1max,dir2min,dir2max]\n"
+     "  dpixel1 ......... width of one pixel in first direction, same unit\n"
+     "                    as distance rcch\n"
+     "  dpixel2 ......... width of one pixel in second direction, same unit\n"
+     "                    as distance rcch\n"
+     "  roi ............. region of interest for the area detector\n"
+     "                    [dir1min, dir1max, dir2min, dir2max]\n"
      "  dir1 ............ first direction of the detector, e.g.: 'x+'\n"
      "  dir2 ............ second direction of the detector, e.g.: 'z+'\n"
      "  tiltazimuth ..... azimuth of the tilt\n"
-     "  tilt ............ tilt of the detector plane (rotation around axis normal to the direction\n"
-     "                    given by the tiltazimuth\n"
-     "  UB .............. orientation matrix and reciprocal space conversion of investigated crystal (3,3)\n"
-     "  sampledis ....... sample displacement vector in same unit as the detector distance\n"
+     "  tilt ............ tilt of the detector plane (rotation around axis\n"
+     "                    normal to the direction given by the tiltazimuth\n"
+     "  UB .............. orientation matrix and reciprocal space conversion\n"
+     "                    of investigated crystal (3, 3)\n"
+     "  sampledis ....... sample displacement vector in same unit as the\n"
+     "                    detector distance\n"
      "  lambda .......... wavelength of the used x-rays \n"
-     "  nthreads ........ number of threads to use in parallel section of the code\n"
+     "  nthreads ........ number of threads to use in parallel section of\n"
+     "                    the code\n"
      "\n"
      "Returns\n"
      "-------\n"
-     " qpos ............ momentum transfer (Npoints*Npix1*Npix2,3)\n"
+     " qpos ............ momentum transfer (Npoints * Npix1 * Npix2, 3)\n"
      "\n"
     },
     {"cbfread", cbfread, METH_VARARGS,
@@ -357,7 +419,7 @@ static PyMethodDef XRU_Methods[] = {
      " Parameters\n"
      " ----------\n"
      "  data:   data stream (character array)\n"
-     "  nx,ny:  number of entries of the two dimensional image\n\n"
+     "  nx, ny: number of entries of the two dimensional image\n\n"
      " Returns\n"
      " -------\n"
      "  the parsed data values as float ndarray\n"
@@ -368,15 +430,15 @@ static PyMethodDef XRU_Methods[] = {
 #if PY_MAJOR_VERSION >= 3
 static struct PyModuleDef moduledef = {
     PyModuleDef_HEAD_INIT,
-    "cxrayutilities", /* m_name */
+    "cxrayutilities",  /* m_name */
     "Python C extension including performance critical parts\n"
-    "of xrayutilities (gridder, qconversion, block-averageing)\n",      /* m_doc */
-    -1,                  /* m_size */
-    XRU_Methods,    /* m_methods */
-    NULL,                /* m_reload */
-    NULL,                /* m_traverse */
-    NULL,                /* m_clear */
-    NULL,                /* m_free */
+    "of xrayutilities (gridder, qconversion, block-averageing)\n",  /* m_doc */
+    -1,                /* m_size */
+    XRU_Methods,       /* m_methods */
+    NULL,              /* m_reload */
+    NULL,              /* m_traverse */
+    NULL,              /* m_clear */
+    NULL,              /* m_free */
 };
 #endif
 
